.. Tomni documentation master file, created by
   sphinx-quickstart on Thu Jan  7 23:46:55 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Tomni documentation!
===================================


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   quickstart
   apidocs
   tutorials



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
